Currently there are a few minor grammatical errors in the comments.
While we are at it we can fix punctuation to be correct and uniform
also.

Correct grammar/punctuation in comments.

Signed-off-by: Tobin C. Harding <to...@kernel.org>
---
 include/linux/slub_def.h | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/include/linux/slub_def.h b/include/linux/slub_def.h
index a3f1fc7e52a6..d2153789bd9f 100644
--- a/include/linux/slub_def.h
+++ b/include/linux/slub_def.h
@@ -81,12 +81,12 @@ struct kmem_cache_order_objects {
  */
 struct kmem_cache {
        struct kmem_cache_cpu __percpu *cpu_slab;
-       /* Used for retriving partial slabs etc */
+       /* Used for retrieving partial slabs, etc. */
        slab_flags_t flags;
        unsigned long min_partial;
-       unsigned int size;      /* The size of an object including meta data */
-       unsigned int object_size;/* The size of an object without meta data */
-       unsigned int offset;    /* Free pointer offset. */
+       unsigned int size;      /* The size of an object including metadata */
+       unsigned int object_size;/* The size of an object without metadata */
+       unsigned int offset;    /* Free pointer offset */
 #ifdef CONFIG_SLUB_CPU_PARTIAL
        /* Number of per cpu partial objects to keep around */
        unsigned int cpu_partial;
-- 
2.20.1

Reply via email to